@@ -9,6 +9,7 @@
 
 #include <limits>
 #include <iosfwd>
+#include "libboardgame_util/Assert.h"
 
 namespace libboardgame_base {
 
@@ -31,6 +32,8 @@ struct CoordPoint
 
     CoordPoint(int x, int y);
 
+    CoordPoint(unsigned x, unsigned y);
+
     bool operator==(CoordPoint p) const;
 
     bool operator!=(CoordPoint p) const;
@@ -56,6 +59,14 @@ inline CoordPoint::CoordPoint(int x, int y)
     this->y = y;
 }
 
+inline CoordPoint::CoordPoint(unsigned x, unsigned y)
+{
+    LIBBOARDGAME_ASSERT(x < numeric_limits<int>::max());
+    LIBBOARDGAME_ASSERT(y < numeric_limits<int>::max());
+    this->x = static_cast<int>(x);
+    this->y = static_cast<int>(y);
+}
+
 inline bool CoordPoint::operator==(CoordPoint p) const
 {
     return x == p.x && y == p.y;
@@ -75,7 +86,7 @@ inline bool CoordPoint::operator!=(CoordPoint p) const
 
 inline CoordPoint CoordPoint::operator+(CoordPoint p) const
 {
-    return CoordPoint(x + p.x, y + p.y);
+    return {x + p.x, y + p.y};
 }
 
 inline CoordPoint& CoordPoint::operator+=(CoordPoint p)
@@ -86,7 +97,7 @@ inline CoordPoint& CoordPoint::operator+=(CoordPoint p)
 
 inline CoordPoint CoordPoint::operator-(CoordPoint p) const
 {
-    return CoordPoint(x - p.x, y - p.y);
+    return {x - p.x, y - p.y};
 }
 
 inline CoordPoint& CoordPoint::operator-=(CoordPoint p)
@@ -97,7 +108,7 @@ inline CoordPoint& CoordPoint::operator-=(CoordPoint p)
 
 inline CoordPoint CoordPoint::null()
 {
-    return CoordPoint(numeric_limits<int>::max(), numeric_limits<int>::max());
+    return {numeric_limits<int>::max(), numeric_limits<int>::max()};
 }
 
 inline bool CoordPoint::is_onboard(int x, int y, unsigned width,
