@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "SgfUtil.h"
 
 #include <algorithm>
@@ -15,7 +11,6 @@
 #include "libboardgame_util/StringUtil.h"
 
 namespace libboardgame_sgf {
-namespace util {
 
 using libboardgame_util::get_letter_coord;
 
@@ -86,25 +81,6 @@ unsigned get_depth(const SgfNode& node)
     return depth;
 }
 
-const char* get_move_annotation(const SgfTree& tree, const SgfNode& node)
-{
-    double goodMove = tree.get_good_move(node);
-    if (goodMove > 1)
-        return "!!";
-    if (goodMove > 0)
-        return "!";
-    double badMove = tree.get_bad_move(node);
-    if (badMove > 1)
-        return "??";
-    if (badMove > 0)
-        return "?";
-    if (tree.is_interesting_move(node))
-        return "!?";
-    if (tree.is_doubtful_move(node))
-        return "?!";
-    return "";
-}
-
 const SgfNode* get_next_earlier_variation(const SgfNode& node)
 {
     auto child = &node;
@@ -215,5 +191,4 @@ bool is_main_variation(const SgfNode& node)
 
 //-----------------------------------------------------------------------------
 
-} // namespace util
 } // namespace libboardgame_sgf
