@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Memory.h"
 
 #ifdef _WIN32
@@ -17,7 +13,7 @@
 #include <unistd.h>
 #endif
 // sysctl() is unsupported on Linux with x32 ABI (last checked on Ubuntu 14.10)
-#if HAVE_SYS_SYSCTL_H && ! (defined __x86_64__ && defined __ILP32__)
+#if defined HAVE_SYS_SYSCTL_H && ! (defined __x86_64__ && defined __ILP32__)
 #include <sys/sysctl.h>
 #endif
 
