@@ -4,13 +4,8 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Test.h"
 
-#include <sstream>
 #include <map>
 #include "libboardgame_util/Assert.h"
 #include "libboardgame_util/Log.h"
@@ -101,6 +96,7 @@ bool run_test(const string& name)
 
 int test_main(int argc, char* argv[])
 {
+    libboardgame_util::LogInitializer log_initializer;
     if (argc < 2)
         return run_all_tests() ? 0 : 1;
     int result = 0;
