@@ -4,15 +4,11 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Assert.h"
 
 #include <list>
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 #include <algorithm>
 #include <functional>
 #include <sstream>
@@ -21,7 +17,7 @@
 #include "Log.h"
 #endif
 
-#if LIBBOARDGAME_DISABLE_LOG
+#ifdef LIBBOARDGAME_DISABLE_LOG
 #include "Unused.h"
 #endif
 
@@ -55,12 +51,12 @@ AssertionHandler::~AssertionHandler()
 
 //----------------------------------------------------------------------------
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 
 void handle_assertion(const char* expression, const char* file, int line)
 {
     static bool is_during_handle_assertion = false;
-#if LIBBOARDGAME_DISABLE_LOG
+#ifdef LIBBOARDGAME_DISABLE_LOG
     LIBBOARDGAME_UNUSED(expression);
     LIBBOARDGAME_UNUSED(file);
     LIBBOARDGAME_UNUSED(line);
