@@ -7,7 +7,6 @@
 #ifndef LIBBOARDGAME_UTIL_TIMER_H
 #define LIBBOARDGAME_UTIL_TIMER_H
 
-#include "Assert.h"
 #include "TimeSource.h"
 
 namespace libboardgame_util {
@@ -16,9 +15,9 @@ class Timer
 {
 public:
     /** Constructor without time source.
-        If constructed without time source, the timer cannot be used befor
+        If constructed without time source, the timer cannot be used before
         reset(TimeSource&) was called. */
-    Timer();
+    Timer() = default;
 
     /** Constructor.
         @param time_source (@ref libboardgame_doc_storesref) */
@@ -36,12 +35,6 @@ private:
     TimeSource* m_time_source = nullptr;
 };
 
-inline double Timer::operator()() const
-{
-    LIBBOARDGAME_ASSERT(m_time_source);
-    return (*m_time_source)() - m_start;
-}
-
 //-----------------------------------------------------------------------------
 
 } // namespace libboardgame_util
