@@ -10,14 +10,13 @@
 #include "BoardConst.h"
 #include "ColorMap.h"
 #include "ColorMove.h"
-#include "Variant.h"
 #include "Geometry.h"
-#include "Grid.h"
 #include "MoveList.h"
 #include "PointList.h"
 #include "PointState.h"
 #include "Setup.h"
 #include "StartingPoints.h"
+#include "Variant.h"
 
 namespace libpentobi_base {
 
@@ -26,6 +25,11 @@ class MoveMarker;
 //-----------------------------------------------------------------------------
 
 /** Blokus board.
+    The implementation is speed-optimized for Monte-Carlo tree search. Only
+    data that is needed during the MCTS search is computed incrementally.
+    For the same reason, it does not provide an undo function, but instead
+    a snapshot state that can can be restored quickly at the start of each
+    MCTS simulation.
     @note @ref libboardgame_avoid_stack_allocation */
 class Board
 {
@@ -230,6 +234,8 @@ public:
 
     PieceSet get_piece_set() const { return m_piece_set; }
 
+    GeometryType get_geometry_type() const { return m_geometry_type; }
+
     bool is_callisto() const { return m_is_callisto; }
 
     /** Whether ties are broken in the current game variant. */
@@ -282,7 +288,8 @@ public:
     string to_string(Move mv, bool with_piece_name = false) const;
 
     /** See BoardConst::from_string() */
-    Move from_string(const string& s) const;
+    bool from_string(Move& mv, const string& s) const {
+        return m_bc->from_string(mv, s); }
 
     bool find_move(const MovePoints& points, Move& mv) const;
 
@@ -384,6 +391,8 @@ private:
 
     PieceSet m_piece_set;
 
+    GeometryType m_geometry_type;
+
     Color::IntType m_nu_colors;
 
     bool m_is_callisto;
@@ -491,11 +500,6 @@ inline bool Board::find_move(const MovePoints& points, Piece piece,
     return m_bc->find_move(points, piece, mv);
 }
 
-inline Move Board::from_string(const string& s) const
-{
-    return m_bc->from_string(s);
-}
-
 inline unsigned Board::get_adj_status(Point p, Color c) const
 {
     LIBBOARDGAME_ASSERT(m_bc->has_adj_status_points(p));
