@@ -7,10 +7,8 @@
 #ifndef LIBPENTOBI_BASE_BOARD_CONST_H
 #define LIBPENTOBI_BASE_BOARD_CONST_H
 
-#include "Geometry.h"
 #include "MoveInfo.h"
 #include "PieceInfo.h"
-#include "PieceTransforms.h"
 #include "PrecompMoves.h"
 #include "SymmetricPoints.h"
 #include "Variant.h"
@@ -136,7 +134,7 @@ public:
     }
 
     /** Only initialized in game variants with central symmetry of board
-        including startign points. */
+        including starting points. */
     const SymmetricPoints& get_symmetrc_points() const
     {
         return m_symmetric_points;
@@ -150,7 +148,7 @@ public:
         files and GTP interface used by Pentobi (version >= 0.2). */
     string to_string(Move mv, bool with_piece_name = false) const;
 
-    Move from_string(const string& s) const;
+    bool from_string(Move& mv, const string& s) const;
 
     /** Sort move points using the ordering used in blksgf files. */
     void sort(MovePoints& points) const;
@@ -281,38 +279,26 @@ inline Piece BoardConst::get_move_piece(Move mv) const
     return get_move_info<MAX_SIZE>(mv).get_piece();
 }
 
-inline Piece BoardConst::get_move_piece(Move mv) const
-{
-    if (m_max_piece_size == 5)
-        return get_move_piece<5>(mv);
-    if (m_max_piece_size == 6)
-        return get_move_piece<6>(mv);
-    if (m_max_piece_size == 7)
-        return get_move_piece<7>(mv);
-    LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
-    return get_move_piece<22>(mv);
-}
-
 inline Range<const Point> BoardConst::get_move_points(Move mv) const
 {
     if (m_max_piece_size == 5)
     {
         auto& info = get_move_info<5>(mv);
-        return Range<const Point>(info.begin(), info.end());
+        return {info.begin(), info.end()};
     }
     if (m_max_piece_size == 6)
     {
         auto& info = get_move_info<6>(mv);
-        return Range<const Point>(info.begin(), info.end());
+        return {info.begin(), info.end()};
     }
     if (m_max_piece_size == 7)
     {
         auto& info = get_move_info<7>(mv);
-        return Range<const Point>(info.begin(), info.end());
+        return {info.begin(), info.end()};
     }
     LIBBOARDGAME_ASSERT(m_max_piece_size == 22);
     auto& info = get_move_info<22>(mv);
-    return Range<const Point>(info.begin(), info.end());
+    return {info.begin(), info.end()};
 }
 
 inline const Point* BoardConst::get_move_points_begin(Move mv) const
