@@ -4,16 +4,15 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "CallistoGeometry.h"
 
+#include <map>
+#include <memory>
 #include "libboardgame_util/Unused.h"
 
 namespace libpentobi_base {
 
+using namespace std;
 using libboardgame_base::CoordPoint;
 
 //-----------------------------------------------------------------------------
@@ -49,8 +48,6 @@ bool is_onboard_callisto(unsigned x, unsigned y, unsigned width,
 
 //-----------------------------------------------------------------------------
 
-map<unsigned, shared_ptr<CallistoGeometry>> CallistoGeometry::s_geometry;
-
 CallistoGeometry::CallistoGeometry(unsigned nu_colors)
 {
     unsigned sz = get_size_callisto(nu_colors);
@@ -60,6 +57,8 @@ CallistoGeometry::CallistoGeometry(unsigned nu_colors)
 
 const CallistoGeometry& CallistoGeometry::get(unsigned nu_colors)
 {
+    static map<unsigned, shared_ptr<CallistoGeometry>> s_geometry;
+
     auto pos = s_geometry.find(nu_colors);
     if (pos != s_geometry.end())
         return *pos->second;
