@@ -4,24 +4,21 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "GembloQGeometry.h"
 
+#include <map>
+#include <memory>
 #include "libboardgame_util/MathUtil.h"
 #include "libboardgame_util/Unused.h"
 
 namespace libpentobi_base {
 
+using namespace std;
 using libboardgame_base::CoordPoint;
 using libboardgame_util::mod;
 
 //-----------------------------------------------------------------------------
 
-map<unsigned, shared_ptr<GembloQGeometry>> GembloQGeometry::s_geometry;
-
 GembloQGeometry::GembloQGeometry(unsigned nu_players)
 {
     unsigned height;
@@ -46,6 +43,8 @@ GembloQGeometry::GembloQGeometry(unsigned nu_players)
 
 const GembloQGeometry& GembloQGeometry::get(unsigned nu_players)
 {
+    static map<unsigned, shared_ptr<GembloQGeometry>> s_geometry;
+
     auto pos = s_geometry.find(nu_players);
     if (pos != s_geometry.end())
         return *pos->second;
