@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "PentobiTree.h"
 
 #include "BoardUpdater.h"
@@ -17,7 +13,7 @@ namespace libpentobi_base {
 
 using libboardgame_sgf::InvalidProperty;
 using libboardgame_sgf::SgfError;
-using libpentobi_base::boardutil::get_current_position_as_setup;
+using libpentobi_base::get_current_position_as_setup;
 
 //-----------------------------------------------------------------------------
 
@@ -43,7 +39,8 @@ const SgfNode& PentobiTree::add_setup(const SgfNode& node, Color c, Move mv)
         set_setup_property(*result, "AE", add_empty);
     auto id = get_setup_prop_id(c);
     auto add_color = get_setup_property(*result, id);
-    if (! add_color.contains(mv) && add_color.size() < add_color.max_size)
+    if (! add_color.contains(mv)
+            && add_color.size() < Setup::PlacementList::max_size)
     {
         add_color.push_back(mv);
         set_setup_property(*result, id, add_color);
@@ -64,17 +61,12 @@ ColorMove PentobiTree::get_move(const SgfNode& node) const
 {
     Color c;
     MovePoints points;
-    if (! libpentobi_base::node_util::get_move(node, m_variant, c, points))
-        return ColorMove::null();
-    if (points.size() == 0)
-        // Older (unreleased?) versions of Pentobi used empty move values
-        // to encode pass moves in search tree dumps but we don't support
-        // pass moves Board anymore.
+    if (! libpentobi_base::get_move(node, m_variant, c, points))
         return ColorMove::null();
     Move mv;
     if (! m_bc->find_move(points, mv))
         throw SgfError("Tree contains illegal move");
-    return ColorMove(c, mv);
+    return {c, mv};
 }
 
 const SgfNode* PentobiTree::get_node_before_move_number(
@@ -124,16 +116,12 @@ Setup::PlacementList PentobiTree::get_setup_property(const SgfNode& node,
     if (node.has_property(id))
         for (auto& s : node.get_multi_property(id))
         {
-            if (result.size() == result.max_size)
+            if (result.size() == Setup::PlacementList::max_size)
                 throw InvalidProperty(id, s);
-            try
-            {
-                result.push_back(m_bc->from_string(s));
-            }
-            catch (const runtime_error&)
-            {
+            Move mv;
+            if (! m_bc->from_string(mv, s))
                 throw InvalidProperty(id, s);
-            }
+            result.push_back(mv);
         }
     return result;
 }
@@ -147,19 +135,6 @@ Variant PentobiTree::get_variant(const SgfNode& root)
     return variant;
 }
 
-bool PentobiTree::has_main_variation_moves() const
-{
-    auto node = &get_root();
-    do
-    {
-        if (has_move(*node))
-            return true;
-        node = node->get_first_child_or_null();
-    }
-    while (node != nullptr);
-    return false;
-}
-
 void PentobiTree::init(unique_ptr<SgfNode>& root)
 {
     Variant variant = get_variant(*root);
@@ -195,7 +170,7 @@ void PentobiTree::keep_only_subtree(const SgfNode& node)
         auto current = node.get_parent_or_null();
         while (current != nullptr)
         {
-            if (has_move(*current) || node_util::has_setup(*current))
+            if (has_move(*current) || has_setup(*current))
             {
                 create_new_setup = true;
                 break;
@@ -210,7 +185,6 @@ void PentobiTree::keep_only_subtree(const SgfNode& node)
         updater.update(*bd, *this, node);
         Setup setup;
         get_current_position_as_setup(*bd, setup);
-        LIBBOARDGAME_ASSERT(! node_util::has_setup(node));
         set_setup(node, setup);
     }
     make_root(node);
@@ -247,7 +221,8 @@ const SgfNode& PentobiTree::remove_setup(const SgfNode& node, Color c,
     else
     {
         auto add_empty = get_setup_property(*result, "AE");
-        if (! add_empty.contains(mv) && add_empty.size() < add_empty.max_size)
+        if (! add_empty.contains(mv)
+                && add_empty.size() < Setup::PlacementList::max_size)
         {
             add_empty.push_back(mv);
             set_setup_property(*result, "AE", add_empty);
