@@ -4,15 +4,11 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "State.h"
 
 #include "libboardgame_util/MathUtil.h"
 #include "libpentobi_base/ScoreUtil.h"
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 #include "libpentobi_base/BoardUtil.h"
 #endif
 
@@ -186,11 +182,11 @@ inline bool State::check_move(Move mv, const MoveInfo<MAX_SIZE>& info,
                 playout_features, total_gamma);
 }
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 string State::dump() const
 {
     ostringstream s;
-    s << "pentobi_mcts::State:\n" << libpentobi_base::boardutil::dump(m_bd);
+    s << "pentobi_mcts::State:\n" << libpentobi_base::dump(m_bd);
     return s.str();
 }
 #endif
@@ -208,8 +204,6 @@ void State::evaluate_multicolor(array<Float, 6>& result)
     if (! m_is_symmetry_broken
             && m_bd.get_nu_onboard_pieces() >= m_symmetry_min_nu_pieces)
     {
-        if (log_simulations)
-            LIBBOARDGAME_LOG("Result: 0.5 (symmetry)");
         result[0] = result[1] = result[2] = result[3] = 0.5;
         return;
     }
@@ -222,12 +216,8 @@ void State::evaluate_multicolor(array<Float, 6>& result)
         res = 0;
     else
         res = 0.5;
-    if (log_simulations)
-        LIBBOARDGAME_LOG("Result color 0: sco=", s, " game_res=", res);
     res += get_quality_bonus(Color(0), res, s)
             + get_quality_bonus_attach_multicolor();
-    if (log_simulations)
-        LIBBOARDGAME_LOG("res=", res);
     result[0] = result[2] = res;
     result[1] = result[3] = 1.f - res;
 }
@@ -255,9 +245,6 @@ void State::evaluate_multiplayer(array<Float, 6>& result)
         Color c(i);
         auto s = m_bd.get_score_multiplayer(c);
         result[i] = game_result[i] + get_quality_bonus(c, game_result[i], s);
-        if (log_simulations)
-            LIBBOARDGAME_LOG("Result sco=", s, " game_res=", game_result[i],
-                             " res=", result[i]);
     }
     if (m_bd.get_variant() == Variant::classic_3)
     {
@@ -276,8 +263,6 @@ void State::evaluate_twocolor(array<Float, 6>& result)
     if (! m_is_symmetry_broken
             && m_bd.get_nu_onboard_pieces() >= m_symmetry_min_nu_pieces)
     {
-        if (log_simulations)
-            LIBBOARDGAME_LOG("Symmetry not broken");
         s = 0;
     }
     else
@@ -289,13 +274,9 @@ void State::evaluate_twocolor(array<Float, 6>& result)
         res = 0;
     else
         res = 0.5;
-    if (log_simulations)
-        LIBBOARDGAME_LOG("Result sco=", s, " game_res=", res);
     res += get_quality_bonus(Color(0), res, s);
     if (m_is_callisto)
         res += get_quality_bonus_attach_twocolor();
-    if (log_simulations)
-        LIBBOARDGAME_LOG("res=", res);
     result[0] = res;
     result[1] = 1.f - res;
 }
@@ -439,8 +420,6 @@ bool State::gen_playout_move_full(PlayerMove<Move>& mv)
         if (m_check_terminate_early && m_bd.get_score_twoplayer(to_play) < 0
             && ! m_has_moves[m_bd.get_second_color(to_play)])
         {
-            if (log_simulations)
-                LIBBOARDGAME_LOG("Terminate early (no moves and neg. score)");
             return false;
         }
         to_play = to_play.get_next(m_nu_colors);
@@ -452,9 +431,6 @@ bool State::gen_playout_move_full(PlayerMove<Move>& mv)
     auto& moves = m_moves[to_play];
     LIBBOARDGAME_ASSERT(! moves.empty());
     auto total_gamma = m_cumulative_gamma[moves.size() - 1];
-    if (log_simulations)
-        LIBBOARDGAME_LOG("Moves: ", moves.size(), ", total_gamma: ",
-                         total_gamma);
     auto begin = m_cumulative_gamma.begin();
     auto end = begin + moves.size();
     auto random = m_random.generate_float(0, total_gamma);
@@ -540,8 +516,8 @@ inline Float State::get_quality_bonus(Color c, Float result, Float score)
 inline Float State::get_quality_bonus_attach_twocolor()
 {
     LIBBOARDGAME_ASSERT(m_bd.get_nu_players() == 2);
-    int n = m_bd.get_attach_points(Color(0)).size()
-            - m_bd.get_attach_points(Color(1)).size();
+    int n = static_cast<int>(m_bd.get_attach_points(Color(0)).size())
+            - static_cast<int>(m_bd.get_attach_points(Color(1)).size());
     for (Point p : m_bd.get_attach_points(Color(0)))
         n -= static_cast<int>(m_bd.is_forbidden(p, Color(0)));
     for (Point p : m_bd.get_attach_points(Color(1)))
@@ -560,10 +536,10 @@ inline Float State::get_quality_bonus_attach_multicolor()
 {
     LIBBOARDGAME_ASSERT(m_bd.get_nu_players() == 2);
     LIBBOARDGAME_ASSERT(m_bd.get_nu_colors() == 4);
-    int n = m_bd.get_attach_points(Color(0)).size()
-            + m_bd.get_attach_points(Color(2)).size()
-            - m_bd.get_attach_points(Color(1)).size()
-            - m_bd.get_attach_points(Color(3)).size();
+    int n = static_cast<int>(m_bd.get_attach_points(Color(0)).size())
+            + static_cast<int>(m_bd.get_attach_points(Color(2)).size())
+            - static_cast<int>(m_bd.get_attach_points(Color(1)).size())
+            - static_cast<int>(m_bd.get_attach_points(Color(3)).size());
     for (Point p : m_bd.get_attach_points(Color(0)))
         n -= static_cast<int>(m_bd.is_forbidden(p, Color(0)));
     for (Point p : m_bd.get_attach_points(Color(2)))
@@ -743,12 +719,12 @@ void State::init_moves_without_gamma(Color c)
     marker.clear(moves);
     auto& pieces = get_pieces_considered<IS_CALLISTO>(c);
     auto& is_forbidden = m_bd.is_forbidden(c);
-    if (m_bd.is_first_piece(c) && ! (MAX_SIZE == 5 && IS_CALLISTO))
+    if (m_bd.is_first_piece(c) && ! IS_CALLISTO)
         add_starting_moves<MAX_SIZE>(c, pieces, false, moves);
     else
     {
         unsigned nu_moves = 0;
-        if (MAX_SIZE == 5 && IS_CALLISTO)
+        if (IS_CALLISTO)
         {
             float total_gamma_dummy;
             add_callisto_one_piece_moves(c, false, total_gamma_dummy, moves,
@@ -789,8 +765,6 @@ void State::init_moves_without_gamma(Color c)
 
 void State::play_expanded_child(Move mv)
 {
-    if (log_simulations)
-        LIBBOARDGAME_LOG("Playing expanded child");
     if (! mv.is_null())
         play_playout(mv);
     else
@@ -802,8 +776,6 @@ void State::play_expanded_child(Move mv)
         // symmetry detection only as a heuristic (playouts and move value
         // initialization)
         m_is_symmetry_broken = true;
-        if (log_simulations)
-            LIBBOARDGAME_LOG(m_bd);
     }
 }
 
@@ -814,8 +786,7 @@ void State::start_search()
     m_bd.set_to_play(m_shared_const.to_play);
     m_bd.take_snapshot();
     m_nu_colors = bd.get_nu_colors();
-    const auto piece_set = bd.get_piece_set();
-    m_is_callisto = (piece_set == PieceSet::callisto);
+    m_is_callisto = bd.is_callisto();
     for (Color c : Color::Range(m_nu_colors))
         m_playout_features[c].init_snapshot(m_bd, c);
     m_bc = &m_bd.get_board_const();
@@ -857,13 +828,7 @@ void State::start_search()
 
 void State::start_simulation(size_t n)
 {
-#if LIBBOARDGAME_DISABLE_LOG
     LIBBOARDGAME_UNUSED(n);
-#endif
-    if (log_simulations)
-        LIBBOARDGAME_LOG("=================================================\n",
-                         "Simulation ", n, "\n",
-                         "=================================================");
     m_bd.restore_snapshot();
     m_force_consider_all_pieces = false;
     auto& geo = m_bd.get_geometry();
