@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <atomic>
 #include <thread>
 #include "Analyze.h"
@@ -24,6 +20,7 @@ using libpentobi_base::Variant;
 
 int main(int argc, char** argv)
 {
+    libboardgame_util::LogInitializer log_initializer;
     atomic<int> result(0);
     try
     {
